@@ -128,6 +128,21 @@ test_that("`NA` is still returned if there are some undefined sensitivity values
   expect_warning(j_index_vec(truth, estimate, na_rm = FALSE), NA)
 })
 
+test_that("works with hardhat case weights", {
+  lst <- data_altman()
+  df <- lst$pathology
+  imp_wgt <- hardhat::importance_weights(seq_len(nrow(df)))
+  freq_wgt <- hardhat::frequency_weights(seq_len(nrow(df)))
+
+  expect_no_error(
+    j_index_vec(df$pathology, df$scan, case_weights = imp_wgt)
+  )
+
+  expect_no_error(
+    j_index_vec(df$pathology, df$scan, case_weights = freq_wgt)
+  ) 
+})
+
 test_that("work with class_pred input", {
   skip_if_not_installed("probably")
 
