@@ -350,3 +350,28 @@ test_that("`probabilities` must be in [0, 1]", {
 test_that("`probabilities` can't be missing", {
   expect_snapshot(error = TRUE, weighted_quantile(1, 1, NA))
 })
+
+test_that("work with class_pred input", {
+  skip_if_not_installed("probably")
+
+  cp_truth <- probably::as_class_pred(two_class_example$truth, which = 1)
+  cp_estimate <- probably::as_class_pred(two_class_example$predicted, which = 2)
+
+  fct_truth <- two_class_example$truth
+  fct_truth[1] <- NA
+
+  fct_estimate <- two_class_example$predicted
+  fct_estimate[2] <- NA
+
+  local_mocked_bindings(
+    .package = "rlang",
+    detect_installed = function(pkg, ...) {
+      FALSE
+    }
+  )
+
+  expect_snapshot(
+    error = TRUE,
+    accuracy_vec(fct_truth, cp_estimate)
+  )
+})
