@@ -256,3 +256,15 @@ test_that("Binary weighted results are the same as scikit-learn", {
     read_pydata("py-pr-curve")$case_weight$binary
   )
 })
+
+# na_rm ------------------------------------------------------------------------
+
+test_that("na_rm = FALSE errors if missing values are present", {
+  df <- two_class_example
+  df$Class1[1] <- NA
+  
+  expect_snapshot(
+    error = TRUE,
+    pr_curve_vec(df$truth, df$Class1, na_rm = FALSE)
+  )
+})
