@@ -59,3 +59,21 @@ test_that("works with infinite time predictions", {
 
   expect_true(!identical(res, exp_res))
 })
+
+test_that("works with hardhat case weights", {
+  lung_surv <- data_lung_surv()
+  lung_surv$case_wts <- rep(2, nrow(lung_surv))
+
+  df <- lung_surv
+
+  df$imp_wgt <- hardhat::importance_weights(lung_surv$case_wts)
+  df$freq_wgt <- hardhat::frequency_weights(lung_surv$case_wts)
+
+  expect_no_error(
+    concordance_survival(df, truth = surv_obj, .pred_time, case_weights = imp_wgt)
+  )
+
+  expect_no_error(
+    concordance_survival(df, truth = surv_obj, .pred_time, case_weights = freq_wgt)
+  )
+})
\ No newline at end of file
